#!/bin/bash

set -e

cd $ROCM_REL_DIR
wget https://github.com/ROCmSoftwarePlatform/rocBLAS/archive/rocm-$PKGVER.tar.gz
wget https://github.com/ROCmSoftwarePlatform/Tensile/archive/rocm-$PKGVER.tar.gz
tar xf rocBLAS-$LDIR.tar.gz
tar xf Tensile-$LDIR.tar.gz

tensile_dir=$(basename Tensile-$LDIR.tar.gz)
rm -rf $ROCM_BUILD_DIR/rocblas
mkdir -p $ROCM_BUILD_DIR/rocblas
cd $ROCM_BUILD_DIR/rocblas

DEST=$OUTPUT/package-rocblas
PRGNAM=rocBLAS
NUMJOBS=${NUMJOBS:-" -j$(expr $(nproc) + 1) "}
BUILD=1

pushd .

export HIPCC_COMPILE_FLAGS_APPEND="-parallel-jobs=$(nproc)"
export HIPCC_LINK_FLAGS_APPEND="-parallel-jobs=$(nproc)"


cmake \
    -Wno-dev \
    -D CMAKE_CXX_COMPILER=${ROCM_INSTALL_DIR}/bin/hipcc \
    -D CMAKE_TOOLCHAIN_FILE=toolchain-linux.cmake \
    -D CMAKE_INSTALL_PREFIX=${ROCM_INSTALL_DIR} \
    -D CMAKE_PREFIX_PATH=${ROCM_INSTALL_DIR}/llvm/lib/cmake/llvm \
    -D amd_comgr_DIR=${ROCM_INSTALL_DIR}/lib/cmake/amd_comgr \
    -D BUILD_WITH_TENSILE=ON \
    -D Tensile_LIBRARY_FORMAT=msgpack \
    -D CMAKE_CXX_FLAGS="${CXXFLAGS} -fcf-protection=none" \
    -D Tensile_TEST_LOCAL_PATH="$ROCM_REL_DIR/$tensile_dir" \
    -G "Unix Makefiles" \
    $ROCM_REL_DIR/rocBLAS-$LDIR

cmake --build .
DESTDIR=$DEST cmake --install .

mkdir -p $DEST/install
cat >> $DEST/install/slack-desc << 'END'
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.
# Line up the first '|' above the ':' following the base package name, and
# the '|' on the right side marks the last column you can put a character in.
# You must make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':' except on otherwise blank lines.

       |-----handy-ruler------------------------------------------------------|
rocBLAS: rocBLAS (Next generation BLAS implementation for ROCm platform)
rocBLAS:
rocBLAS: rocBLAS is the ROCm Basic Linear Algebra Subprograms (BLAS) library.
rocBLAS: rocBLAS is implemented in the HIP programming language and optimized
rocBLAS: for AMD GPUs.
rocBLAS:
rocBLAS:
rocBLAS:
rocBLAS:
rocBLAS:
rocBLAS:
END

cd $DEST
makepkg -l y -c n $OUTPUT/$PRGNAM-$PKGVER-$ARCH-${BUILD}$TAG.txz

popd

